[java-identity-provider] branch main updated: Fix spelling.

Scott Cantor cantor.2 at osu.edu
Tue Jan 25 21:25:20 UTC 2022


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-identity-provider.

View the commit online:
http://git.shibboleth.net/view/?p=java-identity-provider.git;a=commit;h=a63ef1b9f3575990afdcec699549f85e350a71ce

The following commit(s) were added to refs/heads/main by this push:
     new a63ef1b9f Fix spelling.
a63ef1b9f is described below

commit a63ef1b9f3575990afdcec699549f85e350a71ce
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Tue Jan 25 16:25:17 2022 -0500

    Fix spelling.
---
 .../shibboleth/idp/test/flows/saml2/SAML2TestResponseValidator.java | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/saml2/SAML2TestResponseValidator.java b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/saml2/SAML2TestResponseValidator.java
index 324ba3e24..85b08545c 100644
--- a/idp-conf/src/test/java/net/shibboleth/idp/test/flows/saml2/SAML2TestResponseValidator.java
+++ b/idp-conf/src/test/java/net/shibboleth/idp/test/flows/saml2/SAML2TestResponseValidator.java
@@ -105,7 +105,7 @@ public class SAML2TestResponseValidator extends SAML2TestStatusResponseTypeValid
     /** Expected attributes. */
     @Nonnull public List<Attribute> expectedDesignatedAttributes;
 
     /** Expected schacHomeOganization attribute. */
     @Nonnull public Attribute homeOrgAttribute;
     
     /** Expected uid attribute. */
@@ -144,11 +144,11 @@ public class SAML2TestResponseValidator extends SAML2TestStatusResponseTypeValid
                 XMLObjectProviderRegistrySupport.getBuilderFactory().<XSAny>getBuilderOrThrow(
                         XSAny.TYPE_NAME);
         
         // the expected schacHomeOganization attribute
         homeOrgAttribute = builder.buildObject();
         homeOrgAttribute.setName("urn:oid:1.3.6.1.4.1.25178.1.2.9");
         homeOrgAttribute.setNameFormat(Attribute.URI_REFERENCE);
-        homeOrgAttribute.setFriendlyName("schacHomeOganization");
+        homeOrgAttribute.setFriendlyName("schacHomeOrganization");
         final XSAny orgValue = anyBuilder.buildObject(AttributeValue.DEFAULT_ELEMENT_NAME);
         orgValue.setTextContent("example.org");
         homeOrgAttribute.getAttributeValues().add(orgValue);
@@ -105,7 +105,7 @@ public class SAML2TestResponseValidator extends SAML2TestStatusResponseTypeValid
     @Nonnull public List<Attribute> expectedDesignatedAttributes;
 
-    /** Expected schacHomeOganization attribute. */
+    /** Expected schacHomeOrganization attribute. */
     @Nonnull public Attribute homeOrgAttribute;
     
@@ -144,11 +144,11 @@ public class SAML2TestResponseValidator extends SAML2TestStatusResponseTypeValid
                         XSAny.TYPE_NAME);
         
-        // the expected schacHomeOganization attribute
+        // the expected schacHomeOrganization attribute
         homeOrgAttribute = builder.buildObject();
         homeOrgAttribute.setName("urn:oid:1.3.6.1.4.1.25178.1.2.9");

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list